==> gedidb-2025.2.4-py3-none-any.whl: gedidb/granule/l4a_granule.py <==
# SPDX-License-Identifier: EUPL-1.2
# Contact: besnard@gfz.de, felix.dombrowski@uni-potsdam.de and ah2174@cam.ac.uk
# SPDX-FileCopyrightText: 2025 Amelia Holcomb
# SPDX-FileCopyrightText: 2025 Felix Dombrowski
# SPDX-FileCopyrightText: 2025 Simon Besnard
# SPDX-FileCopyrightText: 2025 Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences
#

from typing import Dict

from gedidb.granule.Granule import granule_handler
from gedidb.beam.l4a_beam import L4ABeam
from gedidb.beam.Beam import beam_handler


class L4AGranule(granule_handler):
    """
    Represents a GEDI Level 4A granule, providing access to its beams and related data.

    This class extends the base Granule class and initializes with a specific file path and
    a field mapping that maps product variables to the corresponding data fields in the granule.

    Attributes:
        field_mapping (Dict[str, str]): A dictionary mapping product variables to HDF5 field names.
    """

    def __init__(self, file_path: str, field_mapping: Dict[str, str]):
        """
        Initialize an L4AGranule object.

        Parameters:
            file_path (str): Path to the GEDI Level 4A granule file (HDF5 format).
            field_mapping (Dict[str, str]): Dictionary containing the mapping of product variables to data fields.
        """
        super().__init__(file_path)
        self.file_path = file_path
        self.field_mapping = field_mapping

    def validate_beam_name(self, beam: str) -> None:
        """
        Validate that the provided beam name exists in the granule.

        Parameters:
            beam (str): The name of the beam to validate.

        Raises:
            ValueError: If the specified beam name is not found in the granule.
        """
        if beam not in self.beam_names:
            raise ValueError(
                f"Invalid beam name '{beam}' in file '{self.file_path}'. "
                f"Valid beam names: {self.beam_names}. Ensure the beam exists in the granule."
            )

    def _beam_from_name(self, beam: str) -> beam_handler:
        """
        Retrieve a specific beam from the granule by name.

        Parameters:
            beam (str): The name of the beam to retrieve (e.g., "BEAM0000").

        Returns:
            L4ABeam: The corresponding L4ABeam object for the given beam name.
        """
        self.validate_beam_name(beam)
        return L4ABeam(self, beam, self.field_mapping)

==> gedidb-2025.2.6-py3-none-any.whl: gedidb/granule/l4a_granule.py <==
# SPDX-License-Identifier: EUPL-1.2
# Contact: besnard@gfz.de, felix.dombrowski@uni-potsdam.de and ah2174@cam.ac.uk
# SPDX-FileCopyrightText: 2025 Amelia Holcomb
# SPDX-FileCopyrightText: 2025 Felix Dombrowski
# SPDX-FileCopyrightText: 2025 Simon Besnard
# SPDX-FileCopyrightText: 2025 Helmholtz Centre Potsdam - GFZ German Research Centre for Geosciences
#

from typing import Dict

from gedidb.beam.Beam import beam_handler
from gedidb.beam.l4a_beam import L4ABeam
from gedidb.granule.Granule import granule_handler


class L4AGranule(granule_handler):
    """
    Represents a GEDI Level 4A granule, providing access to its beams and related data.

    This class extends the base Granule class and initializes with a specific file path and
    a field mapping that maps product variables to the corresponding data fields in the granule.

    Attributes:
        field_mapping (Dict[str, str]): A dictionary mapping product variables to HDF5 field names.
    """

    def __init__(self, file_path: str, field_mapping: Dict[str, str]):
        """
        Initialize an L4AGranule object.

        Parameters:
            file_path (str): Path to the GEDI Level 4A granule file (HDF5 format).
            field_mapping (Dict[str, str]): Dictionary containing the mapping of product variables to data fields.
        """
        self.field_mapping = (
            field_mapping  # Initialize early to avoid missing attributes
        )

        try:
            super().__init__(file_path)  # Call parent constructor
            if not self._is_open:
                raise RuntimeError(
                    f"Failed to initialize L4CGranule: {file_path} could not be opened."
                )
        except Exception as e:
            print(f"Error initializing L4CGranule for {file_path}: {e}")
            self.file_path = (
                file_path  # Ensure this is always set to avoid AttributeError
            )
            self._is_open = False  # Mark as not open

    def validate_beam_name(self, beam: str) -> None:
        """
        Validate that the provided beam name exists in the granule.

        Parameters:
            beam (str): The name of the beam to validate.

        Raises:
            ValueError: If the specified beam name is not found in the granule.
        """
        if not self._is_open:
            raise RuntimeError(
                f"Cannot validate beams; granule file '{self.file_path}' is not open."
            )

        if beam not in self.beam_names:
            raise ValueError(
                f"Invalid beam name '{beam}' in file '{self.file_path}'. "
                f"Valid beam names: {self.beam_names}. Ensure the beam exists in the granule."
            )

    def _beam_from_name(self, beam: str) -> beam_handler:
        """
        Retrieve a specific beam from the granule by name.

        Parameters:
            beam (str): The name of the beam to retrieve (e.g., "BEAM0000").

        Returns:
            L4ABeam: The corresponding L4ABeam object for the given beam name.
        """
        self.validate_beam_name(beam)
        return L4ABeam(self, beam, self.field_mapping)
